@@ -1,9 +1,9 @@
 import construct
 
-from mercury_engine_data_structures.formats import BaseResource, game_model_root
+from mercury_engine_data_structures.formats import BaseResource, standard_format
 from mercury_engine_data_structures.game_check import Game
 
-BRSA = game_model_root.create('CSubAreaManager', 0x02010002)
+BRSA = standard_format.game_model('CSubAreaManager', 0x02010002)
 
 
 class Brsa(BaseResource):
